@@ -14,6 +14,7 @@
 #'   in the Unicode punctuation class [P] will be removed.
 #' @inheritParams valuetype
 #' @param case_insensitive logical; if \code{TRUE}, ignore case when matching
+#' @param join logical; if \code{TRUE}, join overlapped compounds
 #' @return a \link{tokens} object in which the token sequences matching the patterns 
 #' in \code{sequences} have been replaced by  compound "tokens" joined by the concatenator
 #' @export
@@ -48,7 +49,7 @@
 #' tokens_compound(toks, collocs)
 tokens_compound <- function(x, sequences,
                     concatenator = "_", valuetype = c("glob", "regex", "fixed"),
-                    case_insensitive = TRUE) {
+                    case_insensitive = TRUE, join = FALSE) {
     UseMethod("tokens_compound")
 }
 
@@ -59,35 +60,31 @@ tokens_compound <- function(x, sequences,
 #' @export
 tokens_compound.tokens <- function(x, sequences,
                    concatenator = "_", valuetype = c("glob", "regex", "fixed"),
-                   case_insensitive = TRUE) {
+                   case_insensitive = TRUE, join = FALSE) {
+    
+    if (!is.tokens(x))
+        stop("x must be a tokens object")
     
-    valuetype <- match.arg(valuetype)
     sequences <- sequence2list(sequences)
     seqs <- as.list(sequences)
     seqs <- seqs[lengths(seqs) > 1] # drop single words
+    
+    # Do nothing if no sequence is given
+    if (!length(seqs))
+        return(x)
+    
+    valuetype <- match.arg(valuetype)
     valuetype <- match.arg(valuetype)
     
     names_org <- names(x)
     attrs_org <- attributes(x)
     types <- types(x)
     
-    # Convert glob or regex to fixed
     seqs_id <- regex2id(seqs, types, valuetype, case_insensitive)
     if(length(seqs_id) == 0) return(x) # do nothing
-    
-    # Make new types
-    seqs_type <- stringi::stri_c_list(lapply(seqs_id, function(y) types[y]), sep=concatenator)
-    
-    
-    # Assign IDs to new types
-    types_id <- match(seqs_type, types)
-    types_new <- seqs_type[is.na(types_id)]
-    types_id[is.na(types_id)] <- seq(length(types) + 1, by=1, length.out=length(types_new))
-    x <- qatd_cpp_tokens_replace(x, seqs_id, types_id)
-    
-    names(x) <- names_org
-    attributes(x) <- attrs_org
-    types(x) <- c(types, types_new)
+    x <- qatd_cpp_tokens_compound(x, seqs_id, types, concatenator, join)
+    x <- reassign_attributes(x, attrs_org, exceptions = "types", attr_only = TRUE)
+    attr(x, "concatenator") <- concatenator
     
     tokens_hashed_recompile(x)
 }
@@ -98,10 +95,10 @@ tokens_compound.tokens <- function(x, sequences,
 #' @export
 tokens_compound.tokenizedTexts <- function(x, sequences, 
                                            concatenator = "_", valuetype = c("glob", "regex", "fixed"),
-                                           case_insensitive = TRUE) {
+                                           case_insensitive = TRUE, join = FALSE) {
     as.tokenizedTexts(tokens_compound(as.tokens(x), sequences = sequences, 
                                       concatenator = concatenator, valuetype = valuetype,
-                                      case_insensitive = TRUE))
+                                      case_insensitive = TRUE, join = join))
 }
 
 
