@@ -1,13 +1,6 @@
-#include <Rcpp.h>
 //#include "dev.h"
 #include "quanteda.h"
-
-// [[Rcpp::plugins(cpp11)]]
-using namespace Rcpp;
-using namespace RcppParallel;
 using namespace quanteda;
-using namespace ngrams;
-
 
 Text detect(Text tokens, 
             const std::vector<std::size_t> &spans,
@@ -38,7 +31,7 @@ struct detect_mt : public Worker{
     const SetNgrams &set_words;
     
     // Constructor
-    detect_mt(Texts &input_, Texts &output_, std::vector<std::size_t> &spans_, SetNgrams &set_words_):
+    detect_mt(Texts &input_, Texts &output_, const std::vector<std::size_t> &spans_, const SetNgrams &set_words_):
               input(input_), output(output_), spans(spans_), set_words(set_words_){}
     
     // parallelFor calles this function with size_t
@@ -84,14 +77,14 @@ List qatd_cpp_tokens_detect(const List &texts_,
     // dev::Timer timer;
     Texts output(input.size());
     // dev::start_timer("Dictionary detect", timer);
-    #if RCPP_PARALLEL_USE_TBB
+#if QUANTEDA_USE_TBB
     detect_mt detect_mt(input, output, spans, set_words);
     parallelFor(0, input.size(), detect_mt);
-    #else
+#else
     for (std::size_t h = 0; h < input.size(); h++) {
         output[h] = detect(input[h], spans, set_words);
     }
-    #endif
+#endif
     // dev::stop_timer("Dictionary detect", timer);
     ListOf<IntegerVector> texts_list = Rcpp::wrap(output);
     return texts_list;
